#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# OBJ - Framework to program bots
#
# obj/db/cmds.py
#
# Copyright 2017,2018 B.H.J Thate
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy 
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights 
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is 
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice don't have to be included.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
# THE SOFTWARE.
#
# 19-04-2018 As the creator of this file, I disclaim all rights on this file. 
#
# Bart Thate
# Heerhugowaard
# The Netherlands

""" commands module. """

## imports

from obj.base import Object, cfg, day, to_day
from obj.collection import Collection
from obj.db import Db
from obj.decorator import oper, echofind
from obj.users import Users

import os
import time

## defines

## vars

db = Db()

## classes

class Log(Object):
    """ log object to save some text. """
    pass

## cmds

def attr(event):
    """ show attributes of an object type. """
    if not event._parsed.args:
         options = ",".join(os.listdir(cfg.workdir))
         event.reply("attr <prefix>, use one of %s" % options)
         return
    prefix = event._parsed.args[0]
    try:
        keys = event._parsed.args[1:]
    except:
        keys = []
    obj = db.last(prefix)
    if obj:
        for key in keys:
            obj = getattr(obj, key, None)
        try:
            res = obj.keys()
        except AttributeError:
            res = []
            for o in obj:
                res.extend(o.keys())
            res = set(res)
        event.reply("\n".join(sorted([x for x in res if not x.startswith("_")])))
    else:
        event.reply("no %s prefix found." % event._parsed.args[0])

@oper
def deleted(event):
    """ show deleted records. """
    event.nodel = True
    nr = 0
    for obj in db.selected(event):
        if "deleted" in dir(obj) and obj.deleted:
            nr += 1
            event.display(obj, txt=str(nr))

def find(event):
    """ present a list of objects based on prompt input. """
    if "c" in event._parsed.enabled:
        c = Collection()
        c += db.selected(event)
        c.display(event)
    else:
        nr = 0
        for o in db.selected(event):
            event.display(o, txt=str(nr))
            nr += 1

def first(event):
    """ show the first record matching the given criteria. """
    obj = db.first(*event._parsed.args)
    if obj:
        event.reply(obj)

@oper
def fix(event):
    """ fix a object by loading and saving it. """
    fn = event._parsed.rest
    fn = os.path.abspath(fn)
    if not fn:
        event.reply("fix <path>")
        return
    if not os.path.isfile(fn):
        event.reply("%s is not a file" % fn)
        return
    o = Object()
    o.load(fn)
    p = o.save()
    event.reply("saved %s" % p)

def last(event):
    """ show last objectect matching the criteria. """
    if not event._parsed.args:
        event.reply("last <prefix> <value>")
        return
    obj = db.last(*event._parsed.args)
    if obj:
        event.reply(obj)
@echofind
def log(event):
    """ log some text. """
    if not event._parsed.rest:
        return
    o = Log()
    o.log = event._parsed.rest
    o.save()
    event.reply("ok 1")

@oper
def restore(event):
    """ set deleted=False in selected records. """
    nr = 0
    event.nodel = True
    for obj in db.selected(event):
        obj.deleted = False
        obj.sync()
        nr += 1
    event.reply("ok %s" % nr)

@oper
def rm(event):
    """ set deleted flag on objects. """
    nr = 0
    for obj in db.selected(event):
        obj.deleted = True
        obj.sync()
        nr += 1
    event.reply("ok %s" % nr)

@oper
def since(event):
    """ show records since given time. """
    if len(event._parsed.args) < 2:
        event.reply("since <prefix> <time>")
        return
    prefix = event._parsed.args[0]
    t = get_time(event._parsed.rest)
    c =  db.since(prefix, event._parsed.rest)
    nr = 0
    for o in c:
        res = o.get(prefix, None)
        if res:
            event.reply("%s %s" % (nr, res))
            nr += 1

def today(event):
    """ show last week's logged objects. """
    event._parsed.start = to_day(day())
    event._parsed.end = time.time()
    nr = 0
    for obj in db.selected(event):
        nr += 1
        event.display(obj, txt=str(nr))

def week(event):
    """ show last week's logged objects. """
    event._parsed.start = to_day(day()) - 7 * 24 * 60 * 60
    event._parsed.end = time.time()
    nr = 0
    for obj in db.selected(event):
        nr += 1
        event.display(obj, txt=str(nr))

def yesterday(event):
    """ show last week's logged objects. """
    event._parsed.start = to_day(day()) - 24 * 60 * 60
    event._parsed.end = to_day(day())
    nr = 0
    for obj in db.selected(event):
        nr += 1
        event.display(obj, txt=str(nr))
