# OBJ - timestamped JSON objects
#
# obj/fleet.py
#
# Copyright 2017,2018 B.H.J Thate
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy 
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights 
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
# copies of the Software, and to permit persons to whom the Software is 
# furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice don't have to be included.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
# THE SOFTWARE.
#
# 02-04-2018 As the creator of this file, I disclaim all rights on this file. 
#
# Bart Thate
# Heerhugowaard
# The Netherlands

"""  fleet module.  """

## imports

from obj.base import Object
from obj.collection import Collection

## classes

class Fleet(Object):

    _bots = [] 

    def __iter__(self):
        for bot in self._bots:
            yield bot

    def announce(self, txt, skip=None):
        for bot in self._bots:
            if skip and skip in bot._id:
                continue
            bot.announce(txt)

    def delete(self, bot):
        if bot in self._bots:
            self._bots.remove(bot)
    
    def get_bot(self, id):
        
        for bot in self._bots:
            if id.lower() in bot._id.lower():
                return bot

    def get_bots(self, id):
        c = Collection()
        for bot in self._bots:
            if id.lower() in bot._id.lower():
                c.append(bot)
        return c

    def get_origin(self, nick):
        """ query bot in the fleet for a nick/origin match. Returns the origin. """
        for bot in self._bots:
            try:
                return bot._userhosts[nick]
            except (KeyError, AttributeError):
                pass

    def register(self, bot):
        if bot not in self._bots:
            self._bots.append(bot)

    def save(self, *args, **kwargs):
        self.bots = self._bots
        super().save(*args, **kwargs)

    def say_id(self, id, channel, txt, type):
        """ echo text to channel on bot matching the given id. """
        bots = self.get_bots(id)
        for bot in bots:
            bot.say(channel, txt, type)
